#
# spec file for package gap-polycyclic
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-polycyclic
Version:        2.16
Release:        1.5
Summary:        GAP: Computation with polycyclic groups
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/polycyclic/
#Git-Clone:     https://github.com/gap-packages/polycyclic
Source:         https://github.com/gap-packages/polycyclic/releases/download/v%version/polycyclic-%version.tar.gz
BuildArch:      noarch
BuildRequires:  gap-rpm-devel
Requires:       gap-alnuth >= 3.0
Requires:       gap-autpgrp >= 1.6
Requires:       gap-core >= 4.9

%description
The Polycyclic package provides a basis for working with polycyclic
groups defined by polycyclic presentations.

The features of this package include
        
* creating a polycyclic group from a polycyclic presentation
* arithmetic in a polycyclic group
* computation with subgroups and factor groups of a polycyclic group
* computation of standard subgroup series such as the derived series,
  the lower central series
* computation of the first and second cohomology
* computation of group extensions
* computation of normalizers and centralizers
* solutions to the conjugacy problems for elements and subgroups
* computation of Torsion and various finite subgroups
* computation of various subgroups of finite index
* computation of teh Schur multiplicator, the non-abelian exterior
  square and the non-abelian tenor square

%prep
%autosetup -n polycyclic-%version

%build

%install
%gappkg_simple_install

%files -f %name.files

%changelog
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.16
  * Add support for random sources to Random method for pcp-groups.
  * Documented IsPcpGroup and IsPcpElementCollection.
  * Increased rank for IsomorphismPcGroup and IsomorphismFpGroup
    methods for pcp-groups, to ensure they are still used when
    all GAP packages are loaded.
  * Fix a bug in `NormalIntersection` which could lead to wrong
    results; this also affected other operations, such `Core`,
    `Intersection`.
  * Fix `PreImagesRepresentative` for trivial homomorphisms (it
    used to return the identity fo the source as preimage for all
    elements in the range, instead of returning fail for all but
    the identity of the range).
* Thu Nov 15 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.14
  * Improved performance of some orbit algorithms by using
    dictionaries.
  * Improved performance of AddToIgs for some examples where it
    previously performed very badly.
  * Added custom IsSingleValued method for group homomorphisms
    whose Source is an polycyclic groups, which can avoid an
    endless loop when the range is an infinite group.
  * Fixed bug in NormalizerPcpGroup, ComplementClassesCR,
    OrbitIntegralAction, and StabilizerIntegralAction, which
    could result in a break loop.
  * Fixed bug in AddToIgs for infinite groups which could result
    in an invalid output leading to strange results.
  * Fixed IsConjugate for pcp group elements to always return
    true and false (instead of an element which conjugates the
    inputs to each other).
  * Deprecated NaturalHomomorphism, use
    NaturalHomomorphismByNormalSubgroup instead (which is a
    standard GAP operation).
  * Replaced immediate methods for IsTorsionFree and
    IsFreeAbelian by implications, which have zero overhead,
    while immediate methods can slow down GAP.
  * Improved performance of UnitriangularPcpGroup for large n
  * Fixed a bug in OneCoboundariesCR which lead to an error in
    OneCohomologyCR.
  * Fixed a bug where the normal closure of an abelian subgroup
    could end up being flagged as abelian, even though it was not.
* Fri May 10 2013 jengelh@inai.de
- Split polycyclic (version 2.11) off the gap RPM package
